Learn R Programming

Rvcg (version 0.18)

checkFaceOrientation: check the orientation of a mesh

Description

check the orientation of a mesh assuming that expansion along normals increases centroid size

Usage

checkFaceOrientation(x, offset = NULL)

Arguments

x

mesh of class mesh3d

offset

numeric: amount to offset the mesh along the vertex normals. If NULL a reasonable value will be estimated.

Value

returns TRUE if mesh is oriented correctly and FALSE otherwise

Details

assuming that a correctly (i.e outward) oriented mesh increases its centroid size when 'growing' outwards, this function tests whether this is the case.

Examples

Run this code
# NOT RUN {
data(dummyhead)
## now we invert faces inwards
checkFaceOrientation(dummyhead.mesh)
dummyinward <- Morpho::invertFaces(dummyhead.mesh)
checkFaceOrientation(dummyinward)
# }

Run the code above in your browser using DataLab