vcgBallPivoting: Ball pivoting surface reconstruction
Description
Ball pivoting surface reconstruction
Usage
vcgBallPivoting(x, radius = 0, clustering = 0.2, angle = pi/2,
deleteFaces = FALSE)
Arguments
x
k x 3 matrix or object of class mesh3d
radius
The radius of the ball pivoting (rolling) over the set of points. Gaps that are larger than the ball radius will not be filled; similarly the small pits that are smaller than the ball radius will be filled. 0 = autoguess.
clustering
Clustering radius (fraction of ball radius). To avoid the creation of too small triangles, if a vertex is found too close to a previous one, it is clustered/merged with it.
angle
Angle threshold (radians). If we encounter a crease angle that is too large we should stop the ball rolling.
deleteFaces
in case x is a mesh and deleteFaces=TRUE, existing faces will be deleted beforehand.
Value
triangular face of class mesh3d
Examples
Run this code# NOT RUN {
require(Morpho)
data(nose)
nosereko <- vcgBallPivoting(shortnose.lm)
# }
Run the code above in your browser using DataLab