powered by
calculate curvature of faces/vertices of a triangular mesh using various methods.
vcgCurve(mesh)
triangular mesh (object of class 'mesh3d')
per vertex gaussian curvature
per vertex mean curvature
per vertex RMS curvature
per face maximum gaussian curvature of adjacent vertices
per face information if it is on the mesh's border (0=FALSE, 1=TRUE)
per vertex information if it is on the mesh's border (0=FALSE, 1=TRUE)
per face maximum mean curvature of adjacent vertices
# NOT RUN { data(humface) curv <- vcgCurve(humface) ##visualise per vertex mean curvature # } # NOT RUN { require(Morpho) meshDist(humface,distvec=curv$meanvb,from=-0.2,to=0.2,tol=0.01) # }
Run the code above in your browser using DataLab