Learn R Programming

Rvcg (version 0.13.1.2)

vcgKDtree: perform kdtree search for 3D-coordinates.

Description

perform kdtree search for 3D-coordinates.

Usage

vcgKDtree(target, query, k, nofPoints = 16, maxDepth = 64, threads = 1)

Arguments

target
n x 3 matrix with 3D coordinates or mesh of class "mesh3d". These coordinates are to be searched.
query
m x 3 matrix with 3D coordinates or mesh of class "mesh3d". We seach the closest coordinates in target for each of these.
k
number of neighbours to find
nofPoints
integer: number of points per cell in the kd-tree (don't change unless you know what you are doing!)
maxDepth
integer: depth of the kd-tree (don't change unless you know what you are doing!)
threads
integer: threads to use in closest point search.

Value

  • a list with
  • indexinteger matrices with indeces of closest points
  • distancescorresponding distances