Learn R Programming

Rvcg (version 0.18)

vcgMeshres: calculates the average edge length of a triangular mesh

Description

calculates the average edge length of a triangular mesh, iterating over all faces.

Usage

vcgMeshres(mesh)

Arguments

mesh

triangular mesh stored as object of class "mesh3d"

Value

res

average edge length (a.k.a. mesh resolution)

edgelength

vector containing lengths for each edge

Examples

Run this code
# NOT RUN {
data(humface)
mres <- vcgMeshres(humface)
#histogram of edgelength distribution
hist(mres$edgelength)
#visualise average edgelength
points( mres$res, 1000, pch=20, col=2, cex=2)
# }

Run the code above in your browser using DataLab