Learn R Programming

Rvcg (version 0.12.2)

vcgUniformRemesh: Resample a mesh uniformly

Description

Resample a mesh uniformly

Usage

vcgUniformRemesh(x, voxelSize = NULL, offset = 0, discretize = FALSE,
  multiSample = FALSE, absDist = FALSE, mergeClost = FALSE,
  silent = FALSE)

Arguments

x
triangular mesh
voxelSize
voxel size for space discretization
offset
Offset of the created surface (i.e. distance of the created surface from the original one).
discretize
If TRUE, the position of the intersected edge of the marching cube grid is not computed by linear interpolation, but it is placed in fixed middle position. As a consequence the resampled object will look severely aliased by a stairstep appearance.
multiSample
If TRUE, the distance field is more accurately compute by multisampling the volume (7 sample for each voxel). Much slower but less artifacts.
absDist
If TRUE, an unsigned distance field is computed. In this case you have to choose a not zero Offset and a double surface is built around the original surface, inside and outside.
mergeClost
logical: merge close vertices
silent
logical: suppress messages

Value

  • resampled mesh

Examples

Run this code
data(humface)
humresample <- vcgUniformRemesh(humface,voxelSize=1,multiSample = TRUE)
require(rgl)
shade3d(humresample,col=3)

Run the code above in your browser using DataLab