Learn R Programming

Rvcg (version 0.6-3)

vcgVFadj: get all faces belonging to each vertex in a mesh

Description

get all faces belonging to each vertex in a mesh

Usage

vcgVFadj(mesh)

Arguments

mesh
triangular mesh

Value

  • list containing one vector per vertex with the indices of the adjacent faces