Learn R Programming

Rvcg (version 0.12.2)

vcgBary: get barycenters of all faces of a triangular mesh

Description

get barycenters of all faces of a triangular mesh

Usage

vcgBary(mesh)

Arguments

mesh
triangular mesh of class "mesh3d"

Value

  • n x 3 matrix containing 3D-coordinates of the barycenters (where n is the number of faces in mesh.

Examples

Run this code
data(humface)
bary <- vcgBary(humface)
require(rgl)
points3d(bary,col=2)
wire3d(humface)

Run the code above in your browser using DataLab