Arguments
x
k x 3 matrix containing 3D-coordinates or object of class "mesh3d".
mesh
triangular surface mesh stored as object of class "mesh3d".
sign
logical: if TRUE, signed distances are returned.
barycentric
logical: if TRUE, barycentric coordinates of the hit
points are returned.
smoothNormals
logical: if TRUE, laplacian smoothed normals are used.
borderchk
logical: request checking if the hit face is at the border of the mesh.