Learn R Programming

Rvcg (version 0.12.2)

vcgCurve: calculate curvature of a triangular mesh

Description

calculate curvature of faces/vertices of a triangular mesh using various methods.

Usage

vcgCurve(mesh)

Arguments

mesh
triangular mesh (object of class 'mesh3d')

Value

  • gaussvbper vertex gaussian curvature
  • meanvbper vertex mean curvature
  • RMSvbper vertex RMS curvature
  • gaussitmaxper face maximum gaussian curvature of adjacent vertices
  • borderitper face information if it is on the mesh's border (0=FALSE, 1=TRUE)
  • bordervbper vertex information if it is on the mesh's border (0=FALSE, 1=TRUE)
  • meanitmaxper face maximum mean curvature of adjacent vertices

Examples

Run this code
data(humface)
curv <- vcgCurve(humface)
##visualise per vertex mean curvature
require(Morpho)
meshDist(humface,distvec=curv$meanvb,from=-0.2,to=0.2,tol=0.01)

Run the code above in your browser using DataLab