Rdocumentation
powered by
Learn R Programming
Rvcg (version 0.12.2)
vcgVFadj: find all faces belonging to each vertex in a mesh
Description
find all faces belonging to each vertex in a mesh and report their indices
Usage
vcgVFadj(mesh)
Arguments
mesh
triangular mesh of class "mesh3d"
Value
list containing one vector per vertex containgin the indices of the adjacent faces